@@ -101,6 +101,7 @@ struct	nsd
         unsigned char   *nsid;
 
 	size_t	ifs;
+	uint8_t grab_ip6_optional;
 
 	/* TCP specific configuration */
 	struct nsd_socket tcp[MAX_INTERFACES];
@@ -118,8 +119,6 @@ struct	nsd
 	
 #ifdef	BIND8_STATS
 
-	char	*named8_stats;
-
 	struct nsdst {
 		time_t	boot;
 		int	period;		/* Produce statistics dump every st_period seconds */
