@@ -92,7 +92,7 @@ log_file(int priority, const char *message)
 	
 	/* Bug #104, add time_t timestamp */
 	fprintf(current_log_file, "[%d] %s[%d]: %s: %s",
-		time(NULL), global_ident, (int) getpid(), priority_text, message);
+		(int)time(NULL), global_ident, (int) getpid(), priority_text, message);
 	length = strlen(message);
 	if (length == 0 || message[length - 1] != '\n') {
 		fprintf(current_log_file, "\n");
@@ -495,7 +495,7 @@ rcode2str(int rc)
         case RCODE_REFUSE:
                 return "REFUSED";
         case RCODE_NOTAUTH:
-                return "NOT AUTHORIZED";
+                return "SERVER NOT AUTHORITATIVE FOR ZONE";
         default:
                 return "UNKNOWN ERROR";
         }
