@@ -503,13 +503,20 @@ precsize_aton (char *cp, char **endptr)
 		}
 	}
 
-	cmval = (mval * 100) + cmval;
+	if(mval >= poweroften[7]) {
+		/* integer overflow possible for *100 */
+		mantissa = mval / poweroften[7];
+		exponent = 9; /* max */
+	}
+	else {
+		cmval = (mval * 100) + cmval;
 	
-	for (exponent = 0; exponent < 9; exponent++)
-		if (cmval < poweroften[exponent+1])
-			break;
+		for (exponent = 0; exponent < 9; exponent++)
+			if (cmval < poweroften[exponent+1])
+				break;
 
-	mantissa = cmval / poweroften[exponent];
+		mantissa = cmval / poweroften[exponent];
+	}
 	if (mantissa > 9)
 		mantissa = 9;
 
@@ -539,7 +546,8 @@ zparser_conv_loc(region_type *region, char *str)
 	int i;
 	int deg, min, secs;	/* Secs is stored times 1000.  */
 	uint32_t lat = 0, lon = 0, alt = 0;
-	uint8_t vszhpvp[4] = {0, 0, 0, 0};
+	/* encoded defaults: version=0 sz=1m hp=10000m vp=10m */
+	uint8_t vszhpvp[4] = {0, 0x12, 0x16, 0x13};
 	char *start;
 	double d;
 			
@@ -569,8 +577,8 @@ zparser_conv_loc(region_type *region, char *str)
 				zc_error_prev_line("space expected after minutes");
 				return NULL;
 			}
+			++str;
 		}
-		++str;
 		
 		/* Seconds? */
 		if (isdigit(*str)) {
@@ -593,12 +601,12 @@ zparser_conv_loc(region_type *region, char *str)
 			}
 
 			if (d < 0.0 || d > 60.0) {
-				zc_error_prev_line("seconds not in range 0.0 .. 6.0");
+				zc_error_prev_line("seconds not in range 0.0 .. 60.0");
 			}
 
-			secs = (int) (d * 1000.0);
+			secs = (int) (d * 1000.0 + 0.5);
+			++str;
 		}
-		++str;
 		
 		switch(*str) {
 		case 'N':
@@ -679,7 +687,7 @@ zparser_conv_loc(region_type *region, char *str)
 		zc_error_prev_line("error parsing altitude");
 	}
 	
-	alt = 10000000 + (int32_t) (d * 100);
+	alt = (uint32_t) (10000000.0 + d * 100 + 0.5);
 
 	if (!isspace(*str) && *str != '\0') {
 		zc_error_prev_line("unexpected character after altitude");
@@ -700,7 +708,7 @@ zparser_conv_loc(region_type *region, char *str)
 	r = alloc_rdata(region, 16);
 	p = (uint32_t *) (r + 1);
 
-	memcpy(p, vszhpvp, 4);
+	memmove(p, vszhpvp, 4);
 	write_uint32(p + 1, lat);
 	write_uint32(p + 2, lon);
 	write_uint32(p + 3, alt);
